@@ -179,11 +179,11 @@ def get_executor_account_id():
 
 
 def get_should_use_eventbridge():
-    return os.environ.get(environmental_variables.SHOULD_FORWARD_EVENTS_TO_EVENTBRIDGE)
+    return os.environ.get(environmental_variables.SHOULD_FORWARD_EVENTS_TO_EVENTBRIDGE, "FALSE").upper() == "TRUE"
 
 
 def get_should_forward_failures_to_opscenter():
-    return os.environ.get(environmental_variables.SHOULD_FORWARD_FAILURES_TO_OPSCENTER)
+    return os.environ.get(environmental_variables.SHOULD_FORWARD_FAILURES_TO_OPSCENTER, "FALSE").upper() == "TRUE"
 
 
 def get_regions():
@@ -213,7 +213,9 @@ def get_on_complete_url():
 
 
 def get_should_delete_rollback_complete_stacks():
-    return os.environ.get(environmental_variables.SHOULD_DELETE_ROLLBACK_COMPLETE_STACKS)
+    return os.environ.get(
+        environmental_variables.SHOULD_DELETE_ROLLBACK_COMPLETE_STACKS
+    )
 
 
 def get_should_use_product_plans():
@@ -221,4 +223,8 @@ def get_should_use_product_plans():
 
 
 def get_spoke_execution_mode_deploy_env():
-    return os.environ.get(environmental_variables.SPOKE_EXECUTION_MODE_DEPLOY_ENV)
\ No newline at end of file
+    return os.environ.get(environmental_variables.SPOKE_EXECUTION_MODE_DEPLOY_ENV)
+
+
+def get_should_use_sns():
+    return os.environ.get(environmental_variables.SHOULD_USE_SNS, "FALSE").upper() == "TRUE"
